==> dasu_3.02.jar: edu/northwestern/dasu/drools/FactDnsTimeout.java <==
/**
 * Dasu Project
 *
 * File:         FactFireAction.java
 * RCS:          $Id$
 * Description:  FactFireAction class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactDnsTimeout class ...
 */
public class FactDnsTimeout extends FactTemplate  {

	private static final long serialVersionUID = 1L;
	
	String server = "";
	long startTime;
	long endTine;
	boolean gaveUp = false;

	public FactDnsTimeout() {
	}
	
	public FactDnsTimeout(String server, long startTime, long endTime, boolean gaveUp) {
		this.server = server;
		this.startTime = startTime;
		this.endTine = endTime;
		this.gaveUp = gaveUp;
	}

	public String getServer() {
		return server;
	}

	public void setServer(String server) {
		this.server = server;
	}

	public long getStartTime() {
		return startTime;
	}

	public void setStartTime(long startTime) {
		this.startTime = startTime;
	}

	public long getEndTine() {
		return endTine;
	}

	public void setEndTine(long endTine) {
		this.endTine = endTine;
	}

	public boolean isGaveUp() {
		return gaveUp;
	}

	public void setGaveUp(boolean gaveUp) {
		this.gaveUp = gaveUp;
	}

	
}

==> dasu_4.11.jar: edu/northwestern/dasu/drools/FactDnsTimeout.java <==
/**
 * Dasu Project
 *
 * File:         FactFireAction.java
 * RCS:          $Id$
 * Description:  FactFireAction class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 24, 2010 at 2:22:53 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactDnsTimeout class ...
 */
public class FactDnsTimeout extends FactTemplate  {

	private static final long serialVersionUID = 1L;
	
	public String dnsIp; 
	public String server = "";
	public long startTime;
	public long endTime;
	public boolean gaveUp = false;

	public FactDnsTimeout() {
	}
	
	public FactDnsTimeout(String server, long startTime, long endTime, boolean gaveUp, String dnsIp) {
		this.server = server;
		this.startTime = startTime;
		this.endTime = endTime;
		this.gaveUp = gaveUp;
		this.dnsIp = dnsIp;
	}

	public String getDnsIp() {
		return dnsIp;
	}
	
	public String getServer() {
		return server;
	}

	public void setServer(String server) {
		this.server = server;
	}

	public long getStartTime() {
		return startTime;
	}

	public void setStartTime(long startTime) {
		this.startTime = startTime;
	}

	public long getEndTine() {
		return endTime;
	}

	public void setEndTine(long endTine) {
		this.endTime = endTine;
	}

	public boolean isGaveUp() {
		return gaveUp;
	}

	public void setGaveUp(boolean gaveUp) {
		this.gaveUp = gaveUp;
	}

	
}
